/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.meldungserstellung;

/**
 * Es wird festgelegt, was beim Starten der Meldungserstellung publiziert wird<br>
 * - Nur aktuelle Änderungen der Meldungen - falls vorhanden<br>
 * - Alles, was vorher (beim letzten Programmlauf) auch publiziert war<br>
 *    *
 * @author Dambach Werke
 * @version $Revision: 1.1 $ / $Date: 2009/01/27 13:54:22 $ / ($Author: Sans $)
 */
public enum PublikationInitial
{
  AENDERUNGEN(0), // Beim Initialisieren werden nur Änderungen publiziert
  ALLES(1);       // Beim Initialisieren wird der vorherige Zustand wiederhergestellt

  /**
   * Numerische Darstellung der Location-Methode
   */
  public final int id;

  /**
   * @param id Id für die initiale Publikation
   * @return die zur übergebenen Id gehörende PublikationInitial-Instanz oder null,
   * falls es zur Id keine Instanz gibt
   */
  public static PublikationInitial get(int id)
  {
    for (PublikationInitial publikation:values())
    {
      if (publikation.id == id)
      {
        return publikation;
      }
    }
    return null;
  }
  
  /**
   * Privater Konstruktor
   */
  private PublikationInitial(int id)
  {
    this.id = id;
  }
  
} 

